@@ -111,7 +111,7 @@ Mx={
   mk_o:                      '〔',         mk_c:                '〕',          #generic mark
   gl_o:                      '〔',         gl_c:                '〕',          #glyph
   fa_o: '〔', fa_o_c: '¤', fa_c_o: '¤', fa_c: '〕',
-  idx_o:                     '▢ ',         idx_c:               '▢ ',
+  idx_o:                     '▩',         idx_c:               '▩',
   nbsp:                      '░',                                              #'▭ '
   br_line:                   '╱',                                              #lB ▌  9612 ┘ ¶
   br_nl:                     '╲',                                              #lB ▌ 』  ┘
@@ -121,11 +121,11 @@ Mx={
   br_page:                   '┼',
   br_page_new:               '╋',
   lnk_o:                     '⌠',          lnk_c:               '⌡',           #'⌈' '⌋' '⌠' '⌡' #Mx[:lnk_o: '◁'; Mx[:lnk_c: '▷' #‹ ›
-  url_o:                     '「',         url_c:               '」',
+  url_o:                     '◘',          url_c:               '◙',
   rel_o:                     '⌈',          rel_c:               '⌋',
   tag_o:                     '⌊',          tag_c:               '⌉',
-  sm_set_o:                  '《',         sm_set_c:            '》',
-  sm_subset_o:               '《 ',        sm_subset_c:         '》',
+  sm_set_o:                  '◢',          sm_set_c:            '◣',
+  sm_subset_o:               '◢',          sm_subset_c:         '◣',
   vline:                     '┆',                                              #  ¦ |
 }
 Mx[:fa_bold_o]=              "#{Mx[:fa_o]}b#{Mx[:fa_o_c]}"
@@ -209,7 +209,7 @@ Px={
   po_subscript_o:            ',{',         po_subscript_c:           '},',
   po_hilite_o:               '*{',         po_hilite_c:              '}*',
   po_monospace_o:            '#{',         po_monospace_c:           '}#',
-  lng_lst: %w[am bg bn br ca cs cy da de el en eo es et eu fi fr ga gl he hi hr hy ia is it la lo lt lv ml mr nl nn no oc pl pt pt_BR ro ru sa se sk sl sq sr sv ta te th tk tr uk ur us vi],
+  lng_lst: %w[am bg bn br ca cs cy da de el en eo es et eu fi fr ga gl he hi hr hy ia is it ja ko la lo lt lv ml mr nl nn no oc pl pt pt_BR ro ru sa se sk sl sq sr sv ta te th tk tr uk ur us vi zh],
   lv1:                       '*',
   lv2:                       '=',
   lv3:                       '=',
@@ -328,8 +328,9 @@ check:
 ¤
  #˝ " λ Ω  β   α π  Ѫ Ж  Я Ѳ  ѳ   Ф ㈣
  Ѳ  ѳ   Ф
- ♩ ♭   ✠   ▭  ▬   ▪
-【】〖〗《》「」
+ ♩ ♭   ✠   ▭  ▬  ▪
+【】〖〗◢ ◣ ◀ ▶ ◘ ◙
+《》「」
  ‹ › ∗ 
 '〔lv1〕','〔lv2〕','〔lv3〕','〔lv4〕','〔lv5〕','〔lv6〕','〔lv7〕','〔lv8〕','〔lv9〕'
 '〔 Ѳ1〕','〔 Ѳ2〕','〔 Ѳ3〕','〔 Ѳ4〕','〔 Ѳ5〕','〔Ѳ6〕','〔Ѳ7〕','〔Ѳ8〕','〔Ѳ9〕'
