@@ -168,6 +168,55 @@ module SiSU_DAL_DocumentStructureExtract
       end
       [str,tags]
     end
+    def rgx_idx_ocn_seg
+      @rgx_idx_ocn_seg=/(.+?)\s*[+](\d+)/
+    end
+    def construct_idx_array_and_hash(idxraw)
+      idx_array_raw=idxraw.scan(/[^;]+/)
+      idx_hash,idx_array,idx_lst={},[],[]
+      idx_array_raw.each do |idx|
+        idx_lst=case idx
+        when /\S+?\s*:/
+          idx_couplet_tmp=[]
+          idx_couplet=idx.scan(/\s*[^:]+\s*/)
+          if idx_couplet[1] =~/[|]/
+            idx_couplet_tmp << idx_couplet[0] << idx_couplet[1].scan(/\s*[^|]+\s*/)
+          else
+            idx_couplet_tmp << idx_couplet[0] << [idx_couplet[1]]
+          end
+          idx_couplet=idx_couplet_tmp
+        else [idx]
+        end
+        term_nodes=[]
+        idx_lst.each do |term_node|
+          case term_node
+          when String
+            term_node=term_node[0].chr.capitalize + term_node[1,term_node.length]
+            term_node=(term_node =~/.+?[+]\d+/) \
+            ? term_node
+            : (term_node + '+0')
+            term_nodes << term_node
+            use,plus=rgx_idx_ocn_seg.match(term_node)[1,2]
+            @use=use.strip
+            idx_hash[@use]={ sub: [], plus: plus } unless idx_hash[@use] and defined? idx_hash[@use]
+          when Array
+            subterm_nodes=[]
+            term_node.each do |subterm_node|
+              subterm_node=(subterm_node =~/.+?[+]\d+/) \
+              ? subterm_node
+              : (subterm_node + '+0')
+              subterm_nodes << subterm_node
+              sub,sub_plus=rgx_idx_ocn_seg.match(subterm_node)[1,2]
+              idx_hash[@use]={ sub: [], plus: 0 } unless idx_hash[@use] and defined? idx_hash[@use]
+              idx_hash[@use][:sub] << {sub.strip => { plus: sub_plus }}
+            end
+            term_nodes << subterm_nodes
+          end
+        end
+        idx_array << term_nodes
+      end
+      { hash: idx_hash, array: idx_array }
+    end
     def identify_parts
       tuned_file=[]
       @tuned_block,@tuned_code=[],[]
@@ -205,9 +254,10 @@ module SiSU_DAL_DocumentStructureExtract
             idx=if t_o=~/^=\{(.+)\}\s*$\Z/m; m=$1
               m=m.split(/\n/).join(' ').
                 gsub(/\s+([|:;])\s+/,'\1').
-                gsub(/\s+([+])\s+/,'\1')
+                gsub(/\s+([+]\d+)\s+/,'\1')
               t_o=t_o.gsub(/\n=\{.+\}\s*$\Z/m,'')
-              m
+              idx_array_and_hash=construct_idx_array_and_hash(m)
+              idx_array_and_hash[:hash]
             else nil
             end
           end
@@ -752,6 +802,7 @@ module SiSU_DAL_DocumentStructureExtract
       node=ocn=ocn_dv=ocn_sp=ocnh=ocnh1=ocnh2=ocnh3=ocnh4=ocnh5=ocnh6=ocno=ocnp=ocnt=ocnc=ocng=ocni=ocnu=0 # h heading, o other, t table, g group, i image
       regex_exclude_ocn_and_node = /#{Rx[:meta]}|^@\S+?:\s|^4~endnotes|^#{Mx[:lv_o]}4:endnotes#{Mx[:lv_c]}|^\^~ |<:e[:_]\d+?>|^<:\#|<:- |<[:!]!4|<hr width|#{Mx[:br_endnotes]}|\A\s*\Z/mi #ocn here #&nbsp; added with Tune.code #¡
       parent=node1=node2=node3=node4=node5=node6=nil
+      @collapsed_lv1=1
       data.each do |dob|
         h={}
         if (dob.obj !~ regex_exclude_ocn_and_node || dob.is==:code) \
@@ -789,27 +840,104 @@ module SiSU_DAL_DocumentStructureExtract
               if ln==1 \
               or ln=~@md.lv1; ocnh1+=1                     #heading
                 node1="1:#{ocnh1};#{ocn}"
+                @collapsed_lv1=1
+                collapsed_level=@collapsed_lv1
                 node,ocn_sp,parent=node1,"h#{ocnh}",0 #FIX
               elsif ln==2 \
               or ln=~@md.lv2; ocnh2+=1
                 node2="2:#{ocnh2};#{ocn}"
-                node,ocn_sp,parent=node2,"h#{ocnh}",node1
+                parent=if node1
+                  @collapsed_lv2=@collapsed_lv1+1
+                  node1
+                else
+                  0
+                end
+                collapsed_level=@collapsed_lv2
+                node,ocn_sp=node2,"h#{ocnh}"
               elsif ln==3 \
               or ln=~@md.lv3; ocnh3+=1
                 node3="3:#{ocnh3};#{ocn}"
-                node,ocn_sp,parent=node3,"h#{ocnh}",node2
+                parent=if node2
+                  @collapsed_lv3=@collapsed_lv2+1
+                  node2
+                elsif node1
+                  puts "warning, incorrect parent or node level, parent is :A~ parent should be :B~ else this node should be :B~ rather than :C~" unless @md.opt.cmd=~/q/
+                  @collapsed_lv3=@collapsed_lv1+1
+                  node1
+                else
+                  puts "warning, incorrect node and or parent level" unless @md.opt.cmd=~/q/
+                  0
+                end
+                collapsed_level=@collapsed_lv3
+                node,ocn_sp=node3,"h#{ocnh}"
               elsif ln==4 \
               or ln=~@md.lv4; ocnh4+=1
                 node4="4:#{ocnh4};#{ocn}"
-                node,ocn_sp,parent=node4,"h#{ocnh}",node3
+                parent=if node3
+                  @collapsed_lv4=@collapsed_lv3+1
+                  node3
+                elsif node2
+                  @collapsed_lv4=@collapsed_lv2+1
+                  node2
+                elsif node1
+                  @collapsed_lv4=@collapsed_lv1+1
+                  node1
+                else
+                  puts "warning, incorrect node and or parent level" unless @md.opt.cmd=~/q/
+                  0
+                end
+                collapsed_level=@collapsed_lv4
+                node,ocn_sp=node4,"h#{ocnh}"
               elsif ln==5 \
               or ln=~@md.lv5; ocnh5+=1
                 node5="5:#{ocnh5};#{ocn}"
-                node,ocn_sp,parent=node5,"h#{ocnh}",node4
+                parent=if node4
+                  @collapsed_lv5=@collapsed_lv4+1
+                  node4
+                elsif node3
+                  puts "warning, incorrect node and or parent level" unless @md.opt.cmd=~/q/
+                  @collapsed_lv5=@collapsed_lv3+1
+                  node3
+                elsif node2
+                  puts "warning, incorrect node and or parent level" unless @md.opt.cmd=~/q/
+                  @collapsed_lv5=@collapsed_lv2+1
+                  node2
+                elsif node1
+                  puts "warning, incorrect node and or parent level" unless @md.opt.cmd=~/q/
+                  @collapsed_lv5=@collapsed_lv1+1
+                  node1
+                else
+                  0
+                end
+                collapsed_level=@collapsed_lv5
+                node,ocn_sp=node5,"h#{ocnh}"
               elsif ln==6 \
               or ln=~@md.lv6; ocnh6+=1
                 node6="6:#{ocnh6};#{ocn}"
-                node,ocn_sp,parent=node6,"h#{ocnh}",node5
+                parent=if node5
+                  @collapsed_lv6=@collapsed_lv5+1
+                  node5
+                elsif node4
+                  puts "warning, incorrect parent or node level, parent is 4~ parent should be 5~ else this node should be 5~ rather than 6~" unless @md.opt.cmd=~/q/
+                  @collapsed_lv6=@collapsed_lv4+1
+                  node4
+                elsif node3
+                  puts "warning, incorrect node and or parent level" unless @md.opt.cmd=~/q/
+                  @collapsed_lv6=@collapsed_lv3+1
+                  node3
+                elsif node2
+                  puts "warning, incorrect node and or parent level" unless @md.opt.cmd=~/q/
+                  @collapsed_lv6=@collapsed_lv2+1
+                  node2
+                elsif node1
+                  puts "warning, incorrect node and or parent level" unless @md.opt.cmd=~/q/
+                  @collapsed_lv6=@collapsed_lv1+1
+                  node1
+                else
+                  0
+                end
+                collapsed_level=@collapsed_lv6
+                node,ocn_sp=node6,"h#{ocnh}"
               end
             else
               ocno+=1
@@ -833,7 +961,7 @@ module SiSU_DAL_DocumentStructureExtract
               end
             end
             if dob.is==:heading
-              dob.ln,dob.node,dob.ocn,dob.odv,dob.osp,dob.parent=ln,node,ocn,ocn_dv,ocn_sp,parent
+              dob.ln,dob.node,dob.ocn,dob.odv,dob.osp,dob.parent,dob.lc=ln,node,ocn,ocn_dv,ocn_sp,parent,collapsed_level
             else
               if dob.of !=:meta \
               && dob.of !=:comment \
