@@ -66,14 +66,12 @@ module SiSU_Commandline
   require_relative 'param_make'                         # param_make.rb
   @@sisu_call_origin_path=nil
   class HeaderCommon
-    def initialize(make_instruct_array)
-      @make_instruct_array=make_instruct_array
-    end
     def sisu_document_make_instructions
       @pagenew=@pagebreak=@pageline=@toc=@lv1=@lv2=@lv3=@lv4=@lv5=@lv6=@num_top=@i18n=@man_section=@emphasis_set_to=@bold_match_list=@italics_match_list=@substitution_match_list=@footer_links=@home_button_links=@links=nil
+      make_instruct_array=SiSU_Env::GetInit.new.sisu_document_make.makefile_read
       @makeset=false
-      if @make_instruct_array
-        @make_instruct_array.each do |para|                                     #% scan document
+      if make_instruct_array
+        make_instruct_array.each do |para|                                     #% scan document
           if para =~/^(?:@make:|@links:)[+-]?\s/
             case para
             when /^@make:(.+)/m                                                #% header processing - make
@@ -153,8 +151,7 @@ module SiSU_Commandline
       @base_stub=@base_path.gsub(u,'\1')
       @a=sisu_glob_rules(a)
       @a.freeze
-      make_instruct_array=SiSU_Env::GetInit.new.sisu_document_make.makefile_read
-      @make_instructions=HeaderCommon.new(make_instruct_array).sisu_document_make_instructions
+      @make_instructions=HeaderCommon.new.sisu_document_make_instructions
       @make_instructions_pod=nil
       init
     end
