@@ -67,9 +67,7 @@ module SiSU_Metadata
       @tag,@inf,@class,@attrib=nil
     end
     def metadata_base
-      meta,tag=[],[]
-      dir=SiSU_Env::InfoEnv.new(@md.fns)
-      base_html="#{dir.url.root}/#{@md.fnb}"
+      meta=[]
       l=SiSU_Env::StandardiseLanguage.new(@md.opt.lng).language
       language=l[:n]
       tr=SiSU_Translate::Source.new(@md,language)
@@ -904,8 +902,6 @@ WOK
     end
     def metadata_tex
       meta=[]
-      dir=SiSU_Env::InfoEnv.new(@md.fns)
-      base_html="#{dir.url.root}/#{@md.fnb}"
       l=SiSU_Env::StandardiseLanguage.new(@md.opt.lng).language
       language=l[:n]
       tr=SiSU_Translate::Source.new(@md,language)
