@@ -63,20 +63,20 @@
 #Ax,Xx,Mx,Rx,Hx,Dx,Px,Ep,Db,Gt,Tex=Array.new(11){{}}
 YEAR='2013'
 Sfx={
-  txt: '.txt',
-  html: '.html',
-  xhtml: '.xhtml',
-  xml: '.xml',
-  xml_sax: '.sax.xml',
-  xml_dom: '.dom.xml',
-  epub: '.epub',
+  txt:        '.txt',
+  html:       '.html',
+  xhtml:      '.xhtml',
+  xml:        '.xml',
+  xml_sax:    '.sax.xml',
+  xml_dom:    '.dom.xml',
+  epub:       '.epub',
   epub_xhtml: '.xhtml',
-  odt: '.odt',
-  pdf: '.pdf',
-  manpage: '.1',
-  info: '.info',
-  texinfo: '.texinfo',
-  sql: '.sql.db',
+  odt:        '.odt',
+  pdf:        '.pdf',
+  manpage:    '.1',
+  info:       '.info',
+  texinfo:    '.texinfo',
+  sql:        '.sql.db',
 }
 Ax={
   tab:                       "\t",
@@ -111,7 +111,7 @@ Mx={
   mk_o:                      '〔',         mk_c:                '〕',          #generic mark
   gl_o:                      '〔',         gl_c:                '〕',          #glyph
   fa_o: '〔', fa_o_c: '¤', fa_c_o: '¤', fa_c: '〕',
-  idx_o:                     '▢ ',         idx_c:               '▢ ',
+  idx_o:                     '▩',         idx_c:               '▩',
   nbsp:                      '░',                                              #'▭ '
   br_line:                   '╱',                                              #lB ▌  9612 ┘ ¶
   br_nl:                     '╲',                                              #lB ▌ 』  ┘
@@ -121,11 +121,11 @@ Mx={
   br_page:                   '┼',
   br_page_new:               '╋',
   lnk_o:                     '⌠',          lnk_c:               '⌡',           #'⌈' '⌋' '⌠' '⌡' #Mx[:lnk_o: '◁'; Mx[:lnk_c: '▷' #‹ ›
-  url_o:                     '「',         url_c:               '」',
+  url_o:                     '◘',          url_c:               '◙',
   rel_o:                     '⌈',          rel_c:               '⌋',
   tag_o:                     '⌊',          tag_c:               '⌉',
-  sm_set_o:                  '《',         sm_set_c:            '》',
-  sm_subset_o:               '《 ',        sm_subset_c:         '》',
+  sm_set_o:                  '◢',          sm_set_c:            '◣',
+  sm_subset_o:               '◢',          sm_subset_c:         '◣',
   vline:                     '┆',                                              #  ¦ |
 }
 Mx[:fa_bold_o]=              "#{Mx[:fa_o]}b#{Mx[:fa_o_c]}"
@@ -209,7 +209,7 @@ Px={
   po_subscript_o:            ',{',         po_subscript_c:           '},',
   po_hilite_o:               '*{',         po_hilite_c:              '}*',
   po_monospace_o:            '#{',         po_monospace_c:           '}#',
-  lng_lst: %w[am bg bn br ca cs cy da de el en eo es et eu fi fr ga gl he hi hr hy ia is it la lo lt lv ml mr nl nn no oc pl pt pt_BR ro ru sa se sk sl sq sr sv ta te th tk tr uk ur us vi],
+  lng_lst: %w[am bg bn br ca cs cy da de el en eo es et eu fi fr ga gl he hi hr hy ia is it ja ko la lo lt lv ml mr nl nn no oc pl pt pt_BR ro ru sa se sk sl sq sr sv ta te th tk tr uk ur us vi zh],
   lv1:                       '*',
   lv2:                       '=',
   lv3:                       '=',
@@ -328,8 +328,9 @@ check:
 ¤
  #˝ " λ Ω  β   α π  Ѫ Ж  Я Ѳ  ѳ   Ф ㈣
  Ѳ  ѳ   Ф
- ♩ ♭   ✠   ▭  ▬   ▪
-【】〖〗《》「」
+ ♩ ♭   ✠   ▭  ▬  ▪
+【】〖〗◢ ◣ ◀ ▶ ◘ ◙
+《》「」
  ‹ › ∗ 
 '〔lv1〕','〔lv2〕','〔lv3〕','〔lv4〕','〔lv5〕','〔lv6〕','〔lv7〕','〔lv8〕','〔lv9〕'
 '〔 Ѳ1〕','〔 Ѳ2〕','〔 Ѳ3〕','〔 Ѳ4〕','〔 Ѳ5〕','〔Ѳ6〕','〔Ѳ7〕','〔Ѳ8〕','〔Ѳ9〕'
@@ -343,8 +344,8 @@ puts %{-\t#{__FILE__}::#{__LINE__}::#{caller}:\n"#{name}"}
 p "\t" + txt.obj + " << #{__FILE__} #{__LINE__} >>"
 p (__FILE__ + ' ' + __LINE__.to_s + '--> ' + dob.inspect) if dob.is==:heading
 data.each {|o| p (__FILE__ + ' ' + __LINE__.to_s + '--> ' + o.inspect) if o.is==:heading}
-puts "#{__FILE__} #{__LINE__} #{para}" if @opt.cmd =~/M/
-puts "#{__FILE__} #{__LINE__} #{t_o}" if @opt.cmd =~/M/
+puts "#{__FILE__} #{__LINE__} #{para}" if @opt.act[:maintenance][:set]==:on
+puts "#{__FILE__} #{__LINE__} #{t_o}" if @opt.act[:maintenance][:set]==:on
  dr ┌  9484   dR ┍  9485   Dr ┎  9486   DR ┏  9487   dl ┐  9488   dL ┑  9489   Dl ┒  9490   LD ┓  9491  ur └  9492   uR ┕  9493   Ur ┖  9494   UR ┗  9495   ul ┘  9496   uL ┙  9497   Ul ┚  9498   UL ┛  9499   vr ├
  dr ┌  9484   dR ┍  9485   Dr ┎  9486   DR ┏  9487   dl ┐  9488   dL ┑  9489   Dl ┒  9490   LD ┓  9491  ur └  9492   uR ┕  9493   Ur ┖  9494   UR ┗  9495   ul ┘  9496   uL ┙  9497   Ul ┚  9498   UL ┛  9499   vr ├
  └  ┘
