@@ -81,12 +81,6 @@ module SiSU_Git
         fnt=@opt.fns[m,2]
       end
       git_path_fnb=@env.processing_path.git + '/' + fnb
-      #unless @opt.cmd =~/q/
-      #  @opt.cmd=~/[MVvz]/ \
-      #  ? SiSU_Screen::Ansi.new(@opt.cmd,'Git path',@git_path[:fnb]).green_hi_blue \
-      #  : SiSU_Screen::Ansi.new(@opt.cmd,'Git path',@git_path[:fnb]).green_title_hi
-      #  SiSU_Screen::Ansi.new(@opt.cmd,"Git path","#{@opt.fns} -> #{@git_path[:fnb]}").warn if @opt.cmd =~/[MVv]/
-      #end
       lng=(@md.opt.lng) ? (@md.opt.lng) : (@md.i18n[0])
       @git_path={
         fnb:       git_path_fnb,
@@ -113,11 +107,17 @@ module SiSU_Git
       #if program_found?
       #  git_commit
       #end
-      unless @opt.cmd =~/q/
-        @opt.cmd=~/[MVvz]/ \
-        ? SiSU_Screen::Ansi.new(@opt.cmd,'Git path',@git_path[:fnb]).green_hi_blue
-        : SiSU_Screen::Ansi.new(@opt.cmd,'Git path',@git_path[:fnb]).green_title_hi
-        SiSU_Screen::Ansi.new(@opt.cmd,"Git path","#{@opt.fns} -> #{@git_path[:fnb]}").warn if @opt.cmd =~/[MVv]/
+      unless @opt.act[:quiet][:set]==:on
+        (@opt.act[:verbose][:set]==:on \
+        || @opt.act[:verbose_plus][:set]==:on \
+        || @opt.act[:maintenance][:set]==:on) \
+        ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Git path',@git_path[:fnb]).green_hi_blue
+        : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Git path',@git_path[:fnb]).green_title_hi
+        if (@opt.act[:verbose][:set]==:on \
+        || @opt.act[:verbose_plus][:set]==:on \
+        || @opt.act[:maintenance][:set]==:on)
+          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"Git path","#{@opt.fns} -> #{@git_path[:fnb]}").warn
+        end
       end
     end
     def program_found?
@@ -190,7 +190,7 @@ module SiSU_Git
       def locate_parse_file
         composite_src=@opt.fns=~/\.ssm$/ ? true : false
         if composite_src \
-        and @opt.cmd.inspect !~/m/
+        and not @opt.act[:dal][:set]==:on
           ##SiSU_Assemble::Composite.new(@opt).read
           #SiSU_DAL::Source.new(@opt).read                                         # -m
           "#{@env.processing_path.composite_file}/#{@opt.fnb}.ssm.sst"
