@@ -911,7 +911,7 @@ WOK
         @ocn=((defined? t_o.ocn) ? t_o.ocn.to_s : nil)
         @headname=((t_o.is==:heading and defined? t_o.name) ? t_o.name : nil)
       else
-        if @md.opt.cmd =~/M/
+        if @md.opt.act[:maintenance][:set]==:on
           p t_o.class
           p caller
         end
