@@ -66,14 +66,12 @@ module SiSU_Commandline
   require_relative 'param_make'                         # param_make.rb
   @@sisu_call_origin_path=nil
   class HeaderCommon
-    def initialize(make_instruct_array)
-      @make_instruct_array=make_instruct_array
-    end
     def sisu_document_make_instructions
       @pagenew=@pagebreak=@pageline=@toc=@lv1=@lv2=@lv3=@lv4=@lv5=@lv6=@num_top=@i18n=@man_section=@emphasis_set_to=@bold_match_list=@italics_match_list=@substitution_match_list=@footer_links=@home_button_links=@links=nil
+      make_instruct_array=SiSU_Env::GetInit.new.sisu_document_make.makefile_read
       @makeset=false
-      if @make_instruct_array
-        @make_instruct_array.each do |para|                                     #% scan document
+      if make_instruct_array
+        make_instruct_array.each do |para|                                     #% scan document
           if para =~/^(?:@make:|@links:)[+-]?\s/
             case para
             when /^@make:(.+)/m                                                #% header processing - make
@@ -153,8 +151,7 @@ module SiSU_Commandline
       @base_stub=@base_path.gsub(u,'\1')
       @a=sisu_glob_rules(a)
       @a.freeze
-      make_instruct_array=SiSU_Env::GetInit.new.sisu_document_make.makefile_read
-      @make_instructions=HeaderCommon.new(make_instruct_array).sisu_document_make_instructions
+      @make_instructions=HeaderCommon.new.sisu_document_make_instructions
       @make_instructions_pod=nil
       init
     end
@@ -633,38 +630,6 @@ module SiSU_Commandline
         else
           { bool: false, set: :na, inst: nil }
         end
-        act[:verbose]=(cmd =~/v/ \
-        || mod.inspect =~/"--verbose"/) \
-        ? { bool: true, set: :on }
-        : { bool: false, set: :na }
-        act[:version_info]=(cmd =~/[vVM]/ \
-        || mod.inspect =~/"--verbose"|"--maintenance"/) \
-        ? { bool: true, set: :on }
-        : { bool: false, set: :na }
-        act[:quiet]=(cmd =~/q/ \
-        || mod.inspect =~/"--quiet"/) \
-        ? { bool: true, set: :on }
-        : { bool: false, set: :na }
-        act[:color_state]=if mod.inspect =~/"--color-on"|"--color"/
-          { bool: true, set: :on }
-        elsif (cmd =~/k/ \
-        || mod.inspect =~/"--color-off"/)
-          { bool: false, set: :off }
-        else { bool: true, set: :na } #fix default color
-        end
-#       act[:color_toggle]=if cmd =~/c/ \
-#       or mod.inspect =~/"--color-toggle"/
-#         true
-#       else false
-#       end
-        act[:maintenance]=(cmd =~/M/ \
-        || mod.inspect =~/"--maintenance|--keep-processing-files"/) \
-        ? { bool: true, set: :on }
-        : { bool: false, set: :na }
-        act[:profile]=(cmd =~/E/ \
-        || mod.inspect =~/"--profile"/) \
-        ? { bool: true, set: :on }
-        : { bool: false, set: :na }
         act[:switch]=if mod.inspect =~/"--switch-off=/
           off_list=mod.join(';').gsub(/^.*--switch-off=['"]?(.+?)(?:['"];.+)?$/,'\1')
           off_list=off_list.scan(/[^,;\s]+/)
@@ -809,10 +774,6 @@ module SiSU_Commandline
           { bool: false, set: :off }
         else { bool: true, set: :na }
         end
-        act[:dal]=(cmd =~/m/ \
-        || mod.inspect =~/"--dal"/) \
-        ? { bool: true, set: :on }
-        : { bool: false, set: :na }
         act[:html]=if (cmd =~/h/ \
         || mod.inspect =~/"--html"/)
           act[:html_scroll]={ bool: true, set: :on }
@@ -981,7 +942,7 @@ module SiSU_Commandline
         ? { bool: true, set: :on }
         : { bool: false, set: :na }
         act[:rsync]=(cmd =~/R/ \
-        || mod.inspect =~/"--rsync"/) \
+        || mod.inspect =~/"--rsync"|"--remote"/) \
         ? { bool: true, set: :on }
         : { bool: false, set: :na }
         act[:zap]=(cmd =~/Z/ \
@@ -1007,6 +968,141 @@ module SiSU_Commandline
         act[:help]=(mod.inspect =~/"--help/) \
         ? { bool: true, set: :on }
         : { bool: false, set: :na }
+        act[:dal]=if (cmd =~/m/ \
+        || mod.inspect =~/"--dal"/)
+          { bool: true, set: :on }
+        elsif (act[:txt][:set]==:on \
+        || act[:xhtml][:set]==:on \
+        || act[:epub][:set]==:on \
+        || act[:html][:set]==:on \
+        || act[:html_seg][:set]==:on \
+        || act[:html_scroll][:set]==:on \
+        || act[:texinfo][:set]==:on \
+        || act[:manpage][:set]==:on \
+        || act[:hash_digests][:set]==:on \
+        || act[:odt][:set]==:on \
+        || act[:pdf][:set]==:on \
+        || act[:pdf_p][:set]==:on \
+        || act[:pdf_l][:set]==:on \
+        || act[:qrcode][:set]==:on \
+        || act[:share_source][:set]==:on \
+        || act[:sisupod][:set]==:on \
+        || act[:concordance][:set]==:on \
+        || act[:xml_dom][:set]==:on \
+        || act[:xml_sax][:set]==:on )
+          { bool: true, set: :on }
+          #if cmd !~/[mn]/
+          #  extra+=if cmd =~/[abegHhIiLNOoPpQTtwXxyz]/ \
+          #  and cmd !~/[mn]/
+          #    'm'                        #% add dal
+        #elsif (act[:txt][:set]==:on \
+        #  { bool: true, set: :on }
+          #  elsif ((cmd =~/[Dd]/ \
+          #  or (mod.inspect =~/--(?:(?:sq)?lite|pg(?:sql)?)/)) \
+          #  and mod.inspect !~/(?:remove|(?:(?:re)?create(?:all)?|dropall|drop)$)/) \
+          #  and cmd !~/[mn]/
+          #    'm'                        #% add dal
+        else
+          { bool: false, set: :na }
+        end
+        act[:manifest]=if mod.inspect =~/"--inc-manifest"/
+          { bool: true, set: :on }
+        elsif mod.inspect =~/"--(?:exc|no)-manifest"/ \
+        || act[:switch][:off].inspect =~/"manifest"/
+          { bool: false, set: :off }
+        elsif (cmd =~/y/ \
+        || mod.inspect =~/"--manifest"/)
+          { bool: true, set: :on }
+        elsif (act[:txt][:set]==:on \
+        || act[:xhtml][:set]==:on \
+        || act[:epub][:set]==:on \
+        || act[:html][:set]==:on \
+        || act[:html_seg][:set]==:on \
+        || act[:html_scroll][:set]==:on \
+        || act[:texinfo][:set]==:on \
+        || act[:manpage][:set]==:on \
+        || act[:hash_digests][:set]==:on \
+        || act[:odt][:set]==:on \
+        || act[:pdf][:set]==:on \
+        || act[:pdf_p][:set]==:on \
+        || act[:pdf_l][:set]==:on \
+        || act[:qrcode][:set]==:on \
+        || act[:share_source][:set]==:on \
+        || act[:sisupod][:set]==:on \
+        || act[:concordance][:set]==:on \
+        || act[:xml_dom][:set]==:on \
+        || act[:xml_sax][:set]==:on )
+          { bool: true, set: :on }
+          ##      if cmd !~/y/
+          ##        extra+=if cmd =~/[abeHhIiNopQSstwXxz]/ \
+          ##        and cmd !~/y/
+          ##          'ym'                       #% add manifest
+        #elsif (act[:txt][:set]==:on \
+        #  { bool: true, set: :on }
+           #        elsif (cmd =~/[Dd]/ \
+           #        or mod.inspect =~/--(?:(?:sq)?lite|pg(?:sql)?)/) \
+           #        and files[0] !~/^remove$/ \
+           #        and cmd !~/y/
+           #          'ym'                       #% add manifest
+        else { bool: true, set: :na }
+        end
+        act[:console_messages] = ''
+        act[:verbose]=if (cmd =~/v/ \
+        || mod.inspect =~/"--verbose"/)
+          act[:console_messages] << ' --verbose '
+          { bool: true, set: :on }
+        else
+          { bool: false, set: :na }
+        end
+        act[:verbose_plus]=if (cmd =~/V/ \
+        || mod.inspect =~/"--very-verbose"/)
+          act[:console_messages] << ' --very-verbose '
+          { bool: true, set: :on }
+        else
+          { bool: false, set: :na }
+        end
+        act[:version_info]=if (cmd =~/[vVM]/ \
+        || mod.inspect =~/"--verbose"|"--maintenance"/)
+          act[:console_messages] << ' --maintenance '
+          { bool: true, set: :on }
+        else
+          { bool: false, set: :na }
+        end
+        act[:quiet]=if (cmd =~/q/ \
+        || mod.inspect =~/"--quiet"/)
+          act[:console_messages] << ' --quiet '
+          { bool: true, set: :on }
+        else
+          { bool: false, set: :na }
+        end
+        act[:color_state]=if mod.inspect =~/"--color-on"|"--color"/
+          act[:console_messages] << ' --color-on '
+          { bool: true, set: :on }
+        elsif (cmd =~/k/ \
+        || mod.inspect =~/"--color-off"/)
+          act[:console_messages] << ' --color-off '
+          { bool: false, set: :off }
+        else { bool: true, set: :na } #fix default color
+        end
+#       act[:color_toggle]=if cmd =~/c/ \
+#       or mod.inspect =~/"--color-toggle"/
+#         true
+#       else false
+#       end
+        act[:maintenance]=if (cmd =~/M/ \
+        || mod.inspect =~/"--maintenance|--keep-processing-files"/)
+          act[:console_messages] << ' --maintenance '
+          { bool: true, set: :on }
+        else
+          { bool: false, set: :na }
+        end
+        act[:profile]=if (cmd =~/E/ \
+        || mod.inspect =~/"--profile"/)
+          act[:console_messages] << ' --color-off '
+          { bool: true, set: :on }
+        else
+          { bool: false, set: :na }
+        end
         @act=act
       end
     end
@@ -1075,6 +1171,6 @@ module SiSU_Commandline
   end
 end
 __END__
-note usually named @opt is carried in Param usually as @md @opt is a subset of
-@md where @md is passed, contents of @opt are available as @md.opt passing @opt
-as well is duplication check for fns & fnb
+note usually named @opt is carried in Param (usually as @md.opt), @opt is a
+subset of @md where @md is passed, contents of @opt are available as @md.opt
+passing @opt as well is duplication check for fns & fnb
